@@ -28,7 +28,7 @@
 #'  
 upper_bounds=function(nplots,ntrts,nblocks) {
   
-  if (nplots%%ntrts != 0 | nplots%%nblocks != 0 | ntrts == 1 | (ntrts+nblocks-1)>nplots ) return(NA) 
+  if (nplots%%ntrts != 0 | nplots%%nblocks != 0 | (ntrts+nblocks-1)>nplots ) return(NA) 
   if (nplots%%(nblocks*ntrts) == 0 ) return(1)  
   nreps = nplots/ntrts #replication
   bsize = nplots/nblocks #block size	
@@ -76,5 +76,5 @@ upper_bounds=function(nplots,ntrts,nblocks) {
     ntrts = temp
     bound = (ntrts - 1)/((ntrts - nblocks) + (nblocks - 1)/bound)
   }			
-  bound
+  round(bound,6)
 }	
